#[non_exhaustive]pub enum ArtifactCacheMaintenance {
Pruned(ArtifactCachePruneReport),
PruneFailed {
message: String,
},
}Expand description
Nonfatal retention attempted as part of a successful cache acquisition.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pruned(ArtifactCachePruneReport)
Configured retention completed under the cache lock.
PruneFailed
Configured retention failed after the requested artifacts were ready.
Implementations
Sourceimpl ArtifactCacheMaintenance
impl ArtifactCacheMaintenance
Sourcepub const fn prune_report(&self) -> Option<ArtifactCachePruneReport>
pub const fn prune_report(&self) -> Option<ArtifactCachePruneReport>
Successful pruning report, or None when maintenance failed.
Sourcepub fn failure_message(&self) -> Option<&str>
pub fn failure_message(&self) -> Option<&str>
Rendered maintenance failure, or None when pruning succeeded.