SharedIncrementalTargetMaintenanceOutcome

Enum SharedIncrementalTargetMaintenanceOutcome 

#[non_exhaustive]
pub enum SharedIncrementalTargetMaintenanceOutcome { Missing { target_dir: PathBuf, }, Skipped { target_dir: PathBuf, lock_wait: Duration, schedule_check: Duration, }, Performed { maintenance: SharedIncrementalTargetMaintenance, schedule_check: Duration, }, Failed { target_dir: PathBuf, lock_wait: Duration, message: String, }, }
Result of interval-limited shared Cargo target maintenance.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Missing

The configured shared target does not exist, so nothing was created or inspected.

Fields

target_dir: PathBuf

Configured target path. A missing path cannot necessarily be canonicalized.



Skipped

A successful matching maintenance pass is still inside the requested interval.

Fields

target_dir: PathBuf

Canonical shared Cargo target directory.

lock_wait: Duration

Time spent waiting for another process using the shared target.

schedule_check: Duration

Time spent checking the small cross-process schedule marker.



Performed

Retention was evaluated under the shared-target lock.

Fields

maintenance: SharedIncrementalTargetMaintenance

Completed retention report.

schedule_check: Duration

Time spent checking the small cross-process schedule marker.



Failed

Integrated best-effort maintenance failed without invalidating the Wasm acquisition.

Fields

target_dir: PathBuf

Canonical shared Cargo target directory.

lock_wait: Duration

Time spent waiting for another process using the shared target.

message: String

Rendered maintenance failure retained for diagnostics.

Implementations

Source

impl SharedIncrementalTargetMaintenanceOutcome

pub fn target_dir(&self) -> &Path

Configured or canonical target associated with this result.

pub const fn maintenance(&self) -> Option<&SharedIncrementalTargetMaintenance>

Completed maintenance report, when retention was evaluated.

pub const fn was_performed(&self) -> bool

Whether retention was evaluated during this call.

pub const fn lock_wait(&self) -> Option<Duration>

Time spent waiting for another process, when the target existed.

pub const fn schedule_check(&self) -> Option<Duration>

Time spent checking the schedule marker, when the target existed.

pub fn failure_message(&self) -> Option<&str>

Rendered integrated maintenance failure, when best-effort handling preserved acquisition.