#[non_exhaustive]pub enum WasmBuildBatchProgressEvent {
BuildStarted {
index: usize,
total: usize,
},
BuildProgress {
index: usize,
event: WasmBuildProgressEvent,
},
BuildFinished {
index: usize,
},
}Expand description
Structured progress for an independent sequence of exact Wasm builds.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BuildStarted
One independently resolved build specification is about to start.
Fields
BuildProgress
Progress forwarded from one independent build.
Fields

event: WasmBuildProgressEventEvent emitted by that build.
BuildFinished
One independent build completed successfully.