#[non_exhaustive]pub enum WasmBuildCacheMaintenance {
Pruned(WasmBuildCachePruneReport),
PruneFailed {
message: String,
},
}Expand description
Nonfatal cache maintenance attempted as part of a Wasm build acquisition.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pruned(WasmBuildCachePruneReport)
Configured retention completed under the existing build lock.
PruneFailed
Configured retention failed after the requested artifacts were ready.
Implementations
Sourceimpl WasmBuildCacheMaintenance
impl WasmBuildCacheMaintenance
Sourcepub const fn prune_report(&self) -> Option<WasmBuildCachePruneReport>
pub const fn prune_report(&self) -> Option<WasmBuildCachePruneReport>
Successful pruning report, or None when maintenance failed.
Sourcepub fn failure_message(&self) -> Option<&str>
pub fn failure_message(&self) -> Option<&str>
Rendered maintenance failure, or None when pruning succeeded.