#[non_exhaustive]pub enum WasmBuildCacheMode {
Isolated,
SharedIncremental {
target_dir: PathBuf,
},
}Expand description
Cargo-target ownership mode for one exact cached Wasm build.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Isolated
Build each exact fingerprint in its own content-addressed Cargo target.
Build misses in caller-owned shared Cargo incremental state, then cache final Wasm files.