#[non_exhaustive]pub enum WasmBuildProgressPhase {
ExactCacheLock,
CargoIdentity,
RustcIdentity,
CargoMetadata,
InputDiscovery,
ContentHashing,
SharedTargetLock,
SharedTargetMaintenance,
CargoBuild,
ArtifactPublication,
ExactCacheMaintenance,
}Expand description
Potentially long phase of one observed Wasm-cache acquisition.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ExactCacheLock
Waiting for exclusive ownership of the exact artifact cache.
CargoIdentity
Reading the Cargo executable identity.
RustcIdentity
Reading the Rust compiler identity.
CargoMetadata
Resolving Cargo’s package graph.
InputDiscovery
Discovering local source and configuration inputs.
ContentHashing
Hashing exact source and configuration contents.
Waiting for exclusive ownership of a shared incremental Cargo target.
Inspecting or clearing a shared incremental Cargo target.
CargoBuild
Compiling the selected Wasm packages.
ArtifactPublication
Validating, copying, hashing, or stamping exact artifacts.
ExactCacheMaintenance
Applying retention to immutable exact-cache entries.