pub fn resolve_cargo_build_inputs(
spec: &WasmBuildSpec,
) -> Result<ResolvedCargoBuildInputs, WasmBuildError>Expand description
Resolve the exact Cargo source, configuration, toolchain, argument, and environment identity.
This performs the same resolution used before and after cached Wasm builds
without running cargo build.