pub struct ArtifactCacheBatchEntry<E> { /* private fields */ }Expand description
One ordered labeled result from a generic artifact batch.
Implementations
Sourceimpl<E> ArtifactCacheBatchEntry<E>
impl<E> ArtifactCacheBatchEntry<E>
Sourcepub const fn result(
&self,
) -> Result<&ArtifactCacheOutcome, &ArtifactCacheBatchFailure<E>>
pub const fn result( &self, ) -> Result<&ArtifactCacheOutcome, &ArtifactCacheBatchFailure<E>>
Structured success or failure for this entry.
Sourcepub fn outcome(&self) -> Option<&ArtifactCacheOutcome>
pub fn outcome(&self) -> Option<&ArtifactCacheOutcome>
Successful artifact outcome, when this entry succeeded.
Sourcepub fn failure(&self) -> Option<&ArtifactCacheBatchFailure<E>>
pub fn failure(&self) -> Option<&ArtifactCacheBatchFailure<E>>
Structured batch failure, when this entry failed.
Sourcepub const fn entry_elapsed(&self) -> Duration
pub const fn entry_elapsed(&self) -> Duration
Complete wall-clock time retained for this entry.
Sourcepub const fn is_success(&self) -> bool
pub const fn is_success(&self) -> bool
Whether this entry completed successfully.
Sourcepub fn into_parts(
self,
) -> (usize, String, Result<ArtifactCacheOutcome, ArtifactCacheBatchFailure<E>>, Duration)
pub fn into_parts( self, ) -> (usize, String, Result<ArtifactCacheOutcome, ArtifactCacheBatchFailure<E>>, Duration)
Consume the entry into its ordered identity, result, and wall time.