pub struct LabeledWasmBuildSpec { /* private fields */ }Expand description
Caller-labeled specification for one exact Wasm batch entry.
The label is report and progress identity only; it does not alter the underlying exact Wasm fingerprint or cache key.
Implementations
Sourceimpl LabeledWasmBuildSpec
impl LabeledWasmBuildSpec
Sourcepub fn new(label: impl Into<String>, spec: WasmBuildSpec) -> Self
pub fn new(label: impl Into<String>, spec: WasmBuildSpec) -> Self
Attach a caller-owned stable label to one Wasm build specification.
Sourcepub const fn spec(&self) -> &WasmBuildSpec
pub const fn spec(&self) -> &WasmBuildSpec
Underlying exact Wasm build specification.
Sourcepub fn into_parts(self) -> (String, WasmBuildSpec)
pub fn into_parts(self) -> (String, WasmBuildSpec)
Consume the entry into its label and Wasm build specification.