pub struct SharedIncrementalTargetMaintenance { /* private fields */ }Expand description
Result of explicit shared Cargo target maintenance.
Implementations
Sourcepub fn target_dir(&self) -> &Path
pub fn target_dir(&self) -> &Path
Canonical shared Cargo target directory maintained under lock.
Sourcepub const fn logical_size_bytes_before(&self) -> u64
pub const fn logical_size_bytes_before(&self) -> u64
Logical bytes observed before applying the policy.
Sourcepub const fn logical_size_bytes_after(&self) -> u64
pub const fn logical_size_bytes_after(&self) -> u64
Logical bytes retained after applying the policy.
Sourcepub const fn last_used_before(&self) -> SystemTime
pub const fn last_used_before(&self) -> SystemTime
Most recent build use observed before applying the policy.
Sourcepub const fn was_cleared(&self) -> bool
pub const fn was_cleared(&self) -> bool
Whether a configured limit caused the mutable target contents to be cleared.
Sourcepub const fn lock_wait(&self) -> Duration
pub const fn lock_wait(&self) -> Duration
Time spent waiting for another process using the shared target.
Sourcepub const fn maintenance(&self) -> Duration
pub const fn maintenance(&self) -> Duration
Time spent measuring and, when required, clearing the target.