pub struct WasmBuildBatchConfig { /* private fields */ }Expand description
Orchestration shared by every entry in one independent Wasm build batch.
Implementations
Sourceimpl WasmBuildBatchConfig
impl WasmBuildBatchConfig
Maintain each distinct shared target once through its first batch entry.
Strictly maintain each distinct shared target at most once per interval.
Batch-owned shared-target maintenance, when configured.