pub struct WasmBuildRecord { /* private fields */ }Expand description
Details shared by built and reused Wasm outcomes.
Implementations
Sourceimpl WasmBuildRecord
impl WasmBuildRecord
Sourcepub const fn fingerprint(&self) -> InputDigest
pub const fn fingerprint(&self) -> InputDigest
Exact build fingerprint used by the atomic cache stamp.
Sourcepub const fn input_digest(&self) -> InputDigest
pub const fn input_digest(&self) -> InputDigest
Exact digest of package sources, lockfile, and configuration inputs.
Sourcepub const fn timings(&self) -> WasmBuildTimings
pub const fn timings(&self) -> WasmBuildTimings
Phase timings captured by the cacheable build operation.
Sourcepub const fn maintenance(&self) -> Option<&WasmBuildCacheMaintenance>
pub const fn maintenance(&self) -> Option<&WasmBuildCacheMaintenance>
Cache maintenance attempted under the build lock, when configured.
Scheduled caller-owned shared-target maintenance, when configured.