pub struct BenchmarkParserConfig {
pub prefixes: Vec<String>,
pub suite_derivation: SuiteDerivation,
pub strict: bool,
}Fields
prefixes: Vec<String>suite_derivation: SuiteDerivationstrict: boolWhen enabled, non-empty lines without a configured marker prefix are reported as malformed markers instead of ignored log noise.