#[non_exhaustive]pub enum BaselinePoolPreparationError<E> {
Recipe {
stage: BaselinePreparationStage,
source: E,
},
Contract(BaselinePoolContractError),
}Expand description
One failed recipe or contract stage while preparing a baseline slot.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Recipe
Caller-owned recipe logic returned an error.
Fields

stage: BaselinePreparationStageFailed lifecycle stage.

source: ECaller-owned structured source error.
Contract(BaselinePoolContractError)
Typed reset or recipe evidence violated the pool contract.