#[non_exhaustive]pub enum BaselinePreparationStage {
Build,
RestoreCanisters,
ResetNonSnapshotState,
DriveToReadiness,
ValidateBuilt,
ValidateRestored,
}Expand description
Recipe stage associated with a structured preparation failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Build
Constructing a new baseline.
RestoreCanisters
Restoring captured canisters.
ResetNonSnapshotState
Resetting state outside the snapshots.
DriveToReadiness
Driving the restored topology to readiness.
ValidateBuilt
Validating a newly built baseline.
ValidateRestored
Validating a restored baseline.
Implementations
Sourceimpl BaselinePreparationStage
impl BaselinePreparationStage
Sourcepub fn default_rebuild_reason(self) -> RebuildReason
pub fn default_rebuild_reason(self) -> RebuildReason
Default rebuild reason used by PocketIcBaselineRecipe::classify_failure.
Recipes that override classification can use this for their fallback after handling a more specific error such as dead PocketIC transport.