#[non_exhaustive]pub enum CycleResetPolicy {
PreserveCurrent,
TopUpTo(u128),
RestoreExactBaseline,
RebuildOnMutation,
}Expand description
Cycle handling required or achieved by one reset.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PreserveCurrent
Do not proactively add or remove cycles before snapshot restoration.
PocketIC may still charge cycles while performing the restore.
TopUpTo(u128)
Add cycles as needed to reach this minimum immediately before restore, without removing excess.
RestoreExactBaseline
Restore the exact balance recorded by the recipe baseline.
RebuildOnMutation
Treat any relevant cycle mutation as requiring slot reconstruction.