PocketIcStartupError

Enum PocketIcStartupError 

#[non_exhaustive]
pub enum PocketIcStartupError { InvalidConfiguration { message: String, }, InvalidServerUrl { server_url: String, message: String, }, Io { operation: &'static str, path: PathBuf, source: Error, }, ServerSpawn { server_binary: PathBuf, source: Error, }, ServerExited { server_binary: PathBuf, status: ExitStatus, elapsed: Duration, stdout: String, stderr: String, }, ReadinessTimeout { server_binary: PathBuf, timeout: Duration, stdout: String, stderr: String, termination_error: Option<String>, }, InvalidServerPort { server_binary: PathBuf, value: String, stdout: String, stderr: String, }, InstanceCreationTimeout { timeout: Duration, stdout: String, stderr: String, termination_error: Option<String>, }, BuilderThreadSpawn { source: Error, }, BuilderPanicked { message: String, }, BuilderDisconnected, }
Structured failure from bounded PocketIC construction.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidConfiguration

The caller supplied a zero timeout or unusable hard TTL.

Fields

message: String


InvalidServerUrl

A caller-provided existing server URL could not be parsed.

Fields

server_url: String
message: String


Io

Preparing or inspecting bounded startup files failed.

Fields

operation: &'static str
path: PathBuf
source: Error


ServerSpawn

The configured PocketIC server process could not be spawned.

Fields

server_binary: PathBuf
source: Error


ServerExited

The managed PocketIC server exited before instance construction completed.

Fields

server_binary: PathBuf
status: ExitStatus
elapsed: Duration
stdout: String
stderr: String


ReadinessTimeout

The managed server did not publish a usable port before the deadline.

Fields

server_binary: PathBuf
timeout: Duration
stdout: String
stderr: String
termination_error: Option<String>


InvalidServerPort

The managed server published an invalid port-file value.

Fields

server_binary: PathBuf
value: String
stdout: String
stderr: String


InstanceCreationTimeout

PocketIC instance creation did not finish before the startup deadline.

Fields

timeout: Duration
stdout: String
stderr: String
termination_error: Option<String>


BuilderThreadSpawn

Spawning the bounded builder worker failed.

Fields

source: Error


BuilderPanicked

Upstream PocketIC construction panicked before returning an instance.

Fields

message: String


BuilderDisconnected

The bounded builder worker ended without returning a result.