#[non_exhaustive]pub enum StandaloneFixturePoolRebuildReason {
DeadPocketIcTransport,
PreviousRestoreFailure,
UnwindWhileLeased,
}Expand description
Why a standalone fixture-pool slot was rebuilt.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DeadPocketIcTransport
PocketIC transport was no longer reachable during snapshot restoration.
PreviousRestoreFailure
A previous restore failed after it may have partially changed the slot.
UnwindWhileLeased
A lease was dropped while its thread was unwinding.