#[non_exhaustive]pub enum TimeResetPolicy {
PreserveCurrent,
RestoreBaseline,
RebuildOnMutation,
}Expand description
PocketIC time handling required or achieved by one reset.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PreserveCurrent
Preserve the current simulator time rather than claiming it was reset.
RestoreBaseline
Restore the exact time recorded by the recipe baseline.
RebuildOnMutation
Treat any relevant time mutation as requiring slot reconstruction.