pub struct CachedPocketIcBaselineGuard<'a, T> { /* private fields */ }Expand description
CachedPocketIcBaselineGuard
Implementations
Sourceimpl<T> CachedPocketIcBaselineGuard<'_, T>
impl<T> CachedPocketIcBaselineGuard<'_, T>
Sourcepub fn pocket_ic(&self) -> &PocketIc
pub fn pocket_ic(&self) -> &PocketIc
Borrow the owned PocketIC instance behind this cached baseline guard.
Sourcepub fn metadata_mut(&mut self) -> &mut T
pub fn metadata_mut(&mut self) -> &mut T
Mutably borrow the captured metadata behind this cached baseline guard.
Sourcepub fn restore(
&self,
controller_id: Principal,
) -> Result<(), ControllerSnapshotError>
pub fn restore( &self, controller_id: Principal, ) -> Result<(), ControllerSnapshotError>
Restore the captured snapshot set without adding cycles.
Sourcepub fn restore_with_funding(
&self,
controller_id: Principal,
funding: SnapshotRestoreFunding,
) -> Result<(), ControllerSnapshotError>
pub fn restore_with_funding( &self, controller_id: Principal, funding: SnapshotRestoreFunding, ) -> Result<(), ControllerSnapshotError>
Restore the captured snapshot set with an explicit cycle-funding policy.