#[non_exhaustive]pub struct CandidCallContext {
pub operation: &'static str,
pub canister_id: Principal,
pub caller: Principal,
pub method: String,
}Expand description
Stable call metadata attached to a contextual call failure.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.operation: &'static strUnderlying PocketIC operation, such as update_call or query_call.
canister_id: PrincipalTarget canister.
caller: PrincipalEffective message caller.
method: StringCanister method name.
Implementations
Sourceimpl CandidCallContext
impl CandidCallContext
Sourcepub fn new(
operation: &'static str,
canister_id: Principal,
caller: Principal,
method: impl Into<String>,
) -> Self
pub fn new( operation: &'static str, canister_id: Principal, caller: Principal, method: impl Into<String>, ) -> Self
Capture the stable call metadata attached to one call failure.
Sourcepub const fn operation(&self) -> &'static str
pub const fn operation(&self) -> &'static str
Read the PocketIC operation name, such as update_call or query_call.
Sourcepub const fn canister_id(&self) -> Principal
pub const fn canister_id(&self) -> Principal
Read the target canister id.