pub struct CanisterDiagnosticLogs { /* private fields */ }Expand description
Successfully fetched canister logs after bounded text conversion.
Implementations
Sourceimpl CanisterDiagnosticLogs
impl CanisterDiagnosticLogs
Sourcepub fn records(&self) -> &[CanisterDiagnosticLogRecord]
pub fn records(&self) -> &[CanisterDiagnosticLogRecord]
Retained records in upstream order.
Sourcepub const fn total_records(&self) -> usize
pub const fn total_records(&self) -> usize
Total number of records returned by PocketIC before bounding.
Sourcepub const fn total_content_bytes(&self) -> usize
pub const fn total_content_bytes(&self) -> usize
Total raw content bytes returned by PocketIC before bounding.
Sourcepub const fn omitted_records(&self) -> usize
pub const fn omitted_records(&self) -> usize
Number of whole records omitted by the configured bounds.
Sourcepub const fn omitted_content_bytes(&self) -> usize
pub const fn omitted_content_bytes(&self) -> usize
Aggregate raw content bytes omitted across retained and omitted records.
Sourcepub const fn was_truncated(&self) -> bool
pub const fn was_truncated(&self) -> bool
Whether either whole records or record content were truncated.