pub struct CanisterInstallError { /* private fields */ }Expand description
Failed canister installation with the created canister id and diagnostics.
Implementations
Sourceimpl CanisterInstallError
impl CanisterInstallError
Sourcepub const fn new(canister_id: Principal, message: String) -> Self
pub const fn new(canister_id: Principal, message: String) -> Self
Capture one install failure for a specific canister id.
Sourcepub fn labeled(
canister_id: Principal,
label: impl Into<String>,
message: impl Into<String>,
) -> Self
pub fn labeled( canister_id: Principal, label: impl Into<String>, message: impl Into<String>, ) -> Self
Capture one labeled install failure for a specific canister id.
Sourcepub const fn canister_id(&self) -> Principal
pub const fn canister_id(&self) -> Principal
Read the canister id that failed to install.