pub struct CanisterLogRenderLimits { /* private fields */ }Expand description
Explicit bounds applied when canister logs are converted to diagnostic text.
Implementations
Sourceimpl CanisterLogRenderLimits
impl CanisterLogRenderLimits
Sourcepub const fn new(record_limit: usize, byte_limit: usize) -> Self
pub const fn new(record_limit: usize, byte_limit: usize) -> Self
Set exact record and aggregate raw-content byte limits.
Zero is valid for either limit and retains no content in that dimension.
Sourcepub const fn record_limit(self) -> usize
pub const fn record_limit(self) -> usize
Maximum number of retained records.
Sourcepub const fn byte_limit(self) -> usize
pub const fn byte_limit(self) -> usize
Maximum aggregate number of retained raw content bytes.