CanisterStatusResult

Struct CanisterStatusResult 

pub struct CanisterStatusResult {
    pub status: CanisterStatusType,
    pub ready_for_migration: bool,
    pub version: u64,
    pub settings: DefiniteCanisterSettings,
    pub module_hash: Option<Vec<u8>>,
    pub memory_size: Nat,
    pub memory_metrics: MemoryMetrics,
    pub cycles: Nat,
    pub reserved_cycles: Nat,
    pub idle_cycles_burned_per_day: Nat,
    pub query_stats: QueryStats,
}
Canister Status Result

Result type of canister_status.

Fields

status: CanisterStatusType

Status of the canister.

ready_for_migration: bool

Indicates whether a stopped canister is ready to be migrated to another subnet (i.e., whether it has empty queues and flushed streams).

version: u64

The canister version.

settings: DefiniteCanisterSettings

Canister settings in effect.

module_hash: Option<Vec<u8>>

A SHA256 hash of the module installed on the canister. This is null if the canister is empty.

memory_size: Nat

The memory size taken by the canister.

memory_metrics: MemoryMetrics

The detailed metrics on the memory consumption of the canister.

cycles: Nat

The cycle balance of the canister.

reserved_cycles: Nat

The reserved cycles balance of the canister.

These are cycles that are reserved by the resource reservation mechanism on storage allocation. See also the CanisterSettings::reserved_cycles_limit parameter in canister settings.

idle_cycles_burned_per_day: Nat

Amount of cycles burned per day.

query_stats: QueryStats

Query statistics.