pub struct SnapshotCleanupFailure { /* private fields */ }Expand description
Failure to remove a snapshot while rolling back a partial capture.
Implementations
Sourceimpl SnapshotCleanupFailure
impl SnapshotCleanupFailure
Sourcepub const fn canister_id(&self) -> Principal
pub const fn canister_id(&self) -> Principal
Read the canister whose captured snapshot could not be removed.
Sourcepub fn response(&self) -> Option<&RejectResponse>
pub fn response(&self) -> Option<&RejectResponse>
Read PocketIC’s structured rejection.
Sourcepub fn panic_message(&self) -> Option<&str>
pub fn panic_message(&self) -> Option<&str>
Read a captured PocketIC panic message, when cleanup did not return a rejection.