Crate ic_testkit

Crate ic_testkit 

Reusable PocketIC-oriented test utilities for IC canister tests.

This crate is intended for host-side test environments (for example via PocketIC) and provides generic helpers such as stable dummy principals, PocketIC re-exports, standalone canister fixtures, generic prebuilt wasm install helpers, retry helpers for PocketIC install throttling, and cached baseline primitives.

Modules

artifacts
Host-side artifact discovery and build helpers for PocketIC tests.
benchmark
Log-marker benchmarking helpers for PocketIC-style test harnesses.
performance
Canister-side benchmark marker emission.
pic
PocketIC re-exports and value-adding host-test harness helpers.

Structs

Account
Account
Fake
Deterministic dummy-value generator for tests.