#[non_exhaustive]pub enum ArtifactCacheError {
InvalidSpec {
message: String,
},
Io {
operation: &'static str,
path: PathBuf,
source: Error,
},
InputsChangedDuringPreparation {
before: InputDigest,
after: InputDigest,
},
InputsChangedDuringBuild {
before: InputDigest,
after: InputDigest,
},
InvalidOutputs {
outputs: Vec<(String, PathBuf)>,
},
UnknownOutput {
name: String,
},
FailedTransactionCleanup {
transaction_error: Box<Self>,
path: PathBuf,
source: Error,
},
}Expand description
Structured failure from transactional artifact caching.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidSpec
The caller supplied an incomplete, ambiguous, or unsafe specification.
Io
A filesystem operation failed.
InputsChangedDuringPreparation
Inputs repeatedly changed while preparing a stable cache acquisition.
InputsChangedDuringBuild
Inputs changed while the caller owned a build transaction.
InvalidOutputs
One or more declared staged outputs were missing or failed validation.
UnknownOutput
A logical output name was not declared by the transaction specification.
FailedTransactionCleanup
Transaction failure cleanup also failed.