#[non_exhaustive]pub enum SharedIncrementalTargetMaintenanceOutcome {
Missing {
target_dir: PathBuf,
},
Skipped {
target_dir: PathBuf,
lock_wait: Duration,
schedule_check: Duration,
},
Performed {
maintenance: SharedIncrementalTargetMaintenance,
schedule_check: Duration,
},
}Expand description
Result of interval-limited shared Cargo target maintenance.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Missing
The configured shared target does not exist, so nothing was created or inspected.
Fields
Skipped
A successful matching maintenance pass is still inside the requested interval.
Fields
Performed
Retention was evaluated under the shared-target lock.
Fields

maintenance: SharedIncrementalTargetMaintenanceCompleted retention report.
Implementations
Sourcepub fn target_dir(&self) -> &Path
pub fn target_dir(&self) -> &Path
Configured or canonical target associated with this result.
Sourcepub const fn maintenance(&self) -> Option<&SharedIncrementalTargetMaintenance>
pub const fn maintenance(&self) -> Option<&SharedIncrementalTargetMaintenance>
Completed maintenance report, when retention was evaluated.
Sourcepub const fn was_performed(&self) -> bool
pub const fn was_performed(&self) -> bool
Whether retention was evaluated during this call.
Sourcepub const fn lock_wait(&self) -> Option<Duration>
pub const fn lock_wait(&self) -> Option<Duration>
Time spent waiting for another process, when the target existed.
Sourcepub const fn schedule_check(&self) -> Option<Duration>
pub const fn schedule_check(&self) -> Option<Duration>
Time spent checking the schedule marker, when the target existed.