pub fn resolve_executable(program: impl AsRef<OsStr>) -> Result<PathBuf>Expand description
Resolve one executable exactly as an artifact-cache tool input.
Paths containing more than one component are resolved directly. Bare
program names are searched through the current PATH. The returned path is
canonical, points to a regular file, and can be passed to
super::ArtifactCacheSpec::with_tool.