pub struct WatchedInputSnapshot { /* private fields */ }Expand description
Newest modification time captured across a set of watched input trees.
Implementations
Sourceimpl WatchedInputSnapshot
impl WatchedInputSnapshot
Sourcepub fn capture(
workspace_root: &Path,
watched_relative_paths: &[&str],
) -> Result<Self>
pub fn capture( workspace_root: &Path, watched_relative_paths: &[&str], ) -> Result<Self>
Recursively capture the newest modification time across all watched inputs.
Sourcepub fn artifact_is_fresh(self, artifact_path: &Path) -> Result<bool>
pub fn artifact_is_fresh(self, artifact_path: &Path) -> Result<bool>
Check whether one artifact is at least as new as the captured inputs.