write_benchmark_report_dir

Function write_benchmark_report_dir 

pub fn write_benchmark_report_dir(
    report: &BenchmarkRunReport,
    path: impl AsRef<Path>,
) -> Result<()>
Write one complete benchmark report into the requested directory.

The directory is caller-owned. Concurrent writers must use unique paths or synchronize access to the same path outside this function.