pub struct CachedPocketIcBaselinePoolGuard<'a, R>where
R: PocketIcBaselineRecipe,{ /* private fields */ }Expand description
Exclusive lease of one validated pooled PocketIC baseline.
Implementations
Sourceimpl<R> CachedPocketIcBaselinePoolGuard<'_, R>where
R: PocketIcBaselineRecipe,
impl<R> CachedPocketIcBaselinePoolGuard<'_, R>where
R: PocketIcBaselineRecipe,
Sourcepub fn invalidate(&mut self, reason: RebuildReason)
pub fn invalidate(&mut self, reason: RebuildReason)
Mark this slot non-reusable with a structured rebuild reason.
Methods from Deref<Target = CachedPocketIcBaseline<R::Metadata>>
Sourcepub fn restore(
&self,
controller_id: Principal,
) -> Result<(), ControllerSnapshotError>
pub fn restore( &self, controller_id: Principal, ) -> Result<(), ControllerSnapshotError>
Restore the captured snapshot set without adding cycles.
Sourcepub fn restore_with_funding(
&self,
controller_id: Principal,
funding: SnapshotRestoreFunding,
) -> Result<(), ControllerSnapshotError>
pub fn restore_with_funding( &self, controller_id: Principal, funding: SnapshotRestoreFunding, ) -> Result<(), ControllerSnapshotError>
Restore the captured snapshot set with an explicit cycle-funding policy.
Sourcepub fn pocket_ic(&self) -> &PocketIc
pub fn pocket_ic(&self) -> &PocketIc
Borrow the owned PocketIC instance behind this cached baseline.
Sourcepub fn snapshot_count(&self) -> usize
pub fn snapshot_count(&self) -> usize
Return the number of canisters captured by this baseline.
Sourcepub fn snapshot_canister_ids(&self) -> impl Iterator<Item = Principal> + '_
pub fn snapshot_canister_ids(&self) -> impl Iterator<Item = Principal> + '_
Iterate over captured canister ids in deterministic principal order.